## [Unreleased]

## [0.1.6] - 2022-07-21
### Python
- added convert primitive utility (#2)
- made gen_dataframe utility more generic (#2)
### Rust
- create `input_set!` macro (#2)
- moved input_set code out to its own file (#2)
- added equality checks to Feature struct (#2)
- added hashing to Feature  (#2)
- added comparison code (#2)

## [0.1.5] - 2022-07-19
### Rust
- Added `feature!` macro
- Added `primitive!` macro